@@ -1,4 +1,5 @@
-#define ARMA_NO_DEBUG
+//#define ARMA_NO_DEBUG
+#define ARMA_USE_CXX14
 #include <RcppArmadillo.h>
 using namespace Rcpp;
 
